#	Generate a vplot file that draws rays
#
#	vpraywft.x par=raywft.p out=raywft.v 
#
# FILES:
#	INPUT:	
#	OUTPUT:
#		stdout:	vplot file
#		
# PARAMETERS:
#	FROM INPUT:
#	FROM PAR:
#		xll,yll,xur,yur the true coordinates of the vplot
#		plotcol=6 	color of plot
#		plotfat=1	fat of plot
#		wantframe=1	=0 no frame; =1 frame
#				
#
# NOTE:
#% end of self doc
#
#-------------
# keyword:
#-------------

integer narray

from par:	integer narray=11

allocate:	real xx(narray),zz(narray)

subroutine submain(narray,xx,zz)

integer narray,iarray
integer plotcol,plotfat,titlesz,titlefat,fat
integer wantframe
integer outfd, output
real xll,yll,xur,yur
real xmin,zmin,xmax,zmax,xrange,zrange,zxrange
real xcenter,zcenter,xscale,zscale
real xmin1,zmin1,xmax1,zmax1,xrange1,zrange1,zxrange1
real xcenter1,zcenter1
real z0,x0,x,z,x1,z1,x2,z2,zp,xp
real theta,theta1,theta2,rr
real xx(narray),zz(narray)
character*50 out
character*50 title
character*150 longstr

# PARAMETERS
#    INPUT 
	from par:	integer plotcol=6,plotfat=1,titlesz=12,titlefat=5
	from par:	integer wantframe=1
	from par:	real xll=3.075,yll=1.37,xur=10.575,yur=8.87
	from par:	character title=" "

#    OUTPUT

# CHECK

# FILES
#   INPUT

#   OUTPUT
	outfd = output()
	if(getch('out','s',out) == 0)
	   call vpfilep(outfd)
	else
	   call vpfile(out)

	call hclose()

# CALCULATION 
	#set parameters
	xmin = xll
	zmin = yll
	xmax = xur
	zmax = yur
	xcenter=0.5*(xmin+xmax)
	zcenter=0.5*(zmin+zmax)
	xrange = xmax-xmin
	zrange = zmax-zmin
	zxrange = sqrt(xrange*xrange+zrange*zrange)
	xmin1 = xmin
	zmin1 = zmin
	xmax1 = xmax
	zmax1 = zmax
	xcenter1 = 0.5*(xmin1+xmax1)
	zcenter1 = 0.5*(zmin1+zmax1)
	xrange1 = xmax1-xmin1
	zrange1 = zmax1-zmin1
	zxrange1 = sqrt(xrange1*xrange1+zrange1*zrange1)

	# set vplot scales
	call vporig(xll,yll)
	call vpuorig(xmin,zmin)
        xscale = (xur-xll)/(xmax-xmin)
        zscale = (yur-yll)/(zmax-zmin)
	call vpscale(xscale,zscale)

	x0 = xcenter1+zxrange1*(xmax1-xmin1)/sqrt((xmax1-xmin1)**2+_
	     (zmax1-zmin1)**2)
	z0 = zcenter1+zxrange1*(zmax1-zmin1)/sqrt((xmax1-xmin1)**2+_
	     (zmax1-zmin1)**2)
	rr = sqrt((xmin1-x0)**2+(zmax1-z0)**2)
	theta1 = atan((z0-zmax1)/(x0-xmin1))
	theta2 = atan((z0-zmin1)/(x0-xmax1))
	call vpcolor(5)
	fat = 4*plotfat
	call vpfat(fat)
	x = x0-rr*cos(theta1)
	z = z0-rr*sin(theta1)
	call vpumove(x,z)
	do iarray = 1,narray
	{
	   theta = theta1+(iarray-1)*(theta2-theta1)/(narray-1)
	   x = x0-rr*cos(theta)
	   z = z0-rr*sin(theta)
	   call vpudraw(x,z)
	}
	xp = x0-rr*cos(0.5*theta1+0.5*theta2)
	zp = z0-rr*sin(0.5*theta1+0.5*theta2)
	call vpcolor(6)
	fat = 2.*plotfat
	call vpfat(fat)
	call vpdash(0.1,0.1,0.1,0.1)
	x1 = xp
	z1 = zp
	x2 = xp+0.3*zxrange1*sin(0.5*theta1+0.5*theta2)
	z2 = zp-0.3*zxrange1*cos(0.5*theta1+0.5*theta2)
	call vpuarrow(x1,z1,x2,z2,0.02*zxrange1)
	x2 = xp+0.3*zxrange1*cos(0.5*theta1+0.5*theta2)
	z2 = zp+0.3*zxrange1*sin(0.5*theta1+0.5*theta2)
	call vpuarrow(x1,z1,x2,z2,0.02*zxrange1)
	call vpdash(0.,0.,0.,0.)
	x0 = xp-0.4*zxrange1*sin(0.5*theta1+0.5*theta2)
	z0 = zp+0.4*zxrange1*cos(0.5*theta1+0.5*theta2)
	rr = 0.4*zxrange1
	call vpcolor(3)
	fat = 4*plotfat
	call vpfat(fat)
	x = x0
	z = z0-rr
	call vpumove(x,z)
	do iarray = 1,narray
	{
	   theta = iarray*2.*atan(1.)/narray
	   x = x0+rr*sin(theta)
	   z = z0-rr*cos(theta)
	   call vpudraw(x,z)
	}
	do iarray = 1,narray
	{
	   theta = (iarray-1)*8*atan(1.)/(narray-1)
	   xx(iarray) = xp+0.008*zxrange1*sin(theta)
	   zz(iarray) = zp+0.008*zxrange1*cos(theta)
	}
	call vpcolor(7)
	call vpufill(xx,zz,narray)
	call vpcolor(7)
	fat = 4*plotfat
	call vpfat(fat)
	call vpupline(xx,zz,narray)

# write title
	call vpcolor(7)
	call vpfat(titlefat)
        call vptjust(2,1)
        x = xcenter
        z = zmax+0.008*titlesz*zxrange
        call vputext(x,z,titlesz,0,title)

	call vpcolor(7)
	call vpfat(2)
	call vptjust(2,3)
	x = xp+0.34*zxrange1*sin(0.5*theta1+0.5*theta2)
	z = zp-0.34*zxrange1*cos(0.5*theta1+0.5*theta2)
	call vputext(x,z,10,0,'\\F15 \\v149 \\F10 t')
	x = xp+0.34*zxrange1*cos(0.5*theta1+0.5*theta2)
	z = zp+0.34*zxrange1*sin(0.5*theta1+0.5*theta2)
	call vputext(x,z,10,0,'\\F15 \\v149 \\^\\F10 g')
	x = 0.3*xmax+0.7*xmin
	z = 0.6*zmax+0.4*zmin
	call vputext(x,z,10,0,'Ray')
	call vptfont(4,0,2)
	x = 0.2*xmax+0.8*xmin
	z = 0.3*zmax+0.7*zmin
	call vputext(x,z,10,0,'Wavefront')

# draw a frame
	if(wantframe != 0.)
	{
	   call vpcolor(7)
	   call vpfat(1)
	   call vpumove(xmin,zmin)
	   call vpudraw(xmin,zmax)
	   call vpudraw(xmax,zmax)
	   call vpudraw(xmax,zmin)
	   call vpudraw(xmin,zmin)
	}
	   
stop
end
